@@ -190,7 +190,7 @@ class Radar(Sensor):
 
         for ping in radar_dict["pings"]:
 
-            self.pings.append(Vector3(ping["x"], ping))
+            self.pings.append(Vector3.from_dict(ping))
 
         self.it_ping = radar_dict["itPing"]
 
